# Welcome to acnaweb-lib-proj 👋
![Version](https://img.shields.io/badge/version-0.1.0-blue.svg?cacheSeconds=2592000)

> acnaweblib is a Python library for testing

### 🏠 [Homepage](https://github.com/acnaweb/acnaweb-lib)


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install acnaweblib.


## Install

```bash
pip install acnaweblib
```

## Usage

```python
from acnaweblib import calculator

# returns 6
result = calculator.add(4,2)

```

## Author

👤 **Antonio Carlos de Lima Junior**

* Website: https://www.linkedin.com/in/acnaweb/
* Github: [@acnaweb](https://github.com/acnaweb)
* LinkedIn: [@acnaweb](https://linkedin.com/in/acnaweb)

## Show your support

Give a ⭐️ if this project helped you!


***
_This README was generated with ❤️ by [readme-md-generator](https://github.com/kefranabg/readme-md-generator)_